@@ -17,11 +17,11 @@
 
 """cubicweb-queueing entity's classes"""
 
-import sys
 import os.path as osp
 from itertools import izip
 import subprocess
 import json
+import threading
 
 from cubicweb import InternalError
 from cubicweb.predicates import (relation_possible, has_related_entities,
@@ -185,7 +185,7 @@ class Queueable(EntityAdapter):
                            'Qresource adapter for thgis entity ?')
         # remove `queuing` entity from queue
         self.entity.reverse_has_qentity[0].cw_delete()
-        self.entity.set_relations(uses_resource=resource)
+        self.entity.cw_set(uses_resource=resource)
         assert resource.reverse_has_resources, self._cw._(
             'resource %s has no queue') % resource
         self.info('starting %s on resource %s', self.entity, resource)
@@ -194,7 +194,7 @@ class Queueable(EntityAdapter):
                                   "async.py")
             authobject = self.prepare_authentication()
             callargs = [str(arg) for arg in
-                        [sys.executable,
+                        ['python',
                          async_path,
                          self._cw.vreg.config.appid,
                          self._cw.vreg.config['zmq-repository-address'],
@@ -205,12 +205,14 @@ class Queueable(EntityAdapter):
                          self._cw.vreg.config.mode]]
             self.info('subprocess call with: %s', ', '.join(callargs))
             def deferred():
-                subprocess.Popen(callargs)
+                child = subprocess.Popen(callargs)
+                thread = threading.Thread(target=child.wait)
+                thread.start()
             return deferred
         else:
             # XXX to deprecate ?
             def deferred():
-                with self._cw.repo.internal_session(safe=True) as session:
+                with self._cw.repo.internal_session() as session:
                     efi = session.entity_from_eid
                     qresource = efi(resource.eid).cw_adapt_to('QResource')
                     entity = efi(self.entity.eid)
@@ -225,7 +227,7 @@ class Queueable(EntityAdapter):
         '''
         res = self.entity.uses_resource[0]
         self.info('releasing resource %s on resource %s', self.entity, res)
-        self.entity.set_relations(uses_resource=None)
+        self.entity.cw_set(uses_resource=None)
 
 
 class QResource(EntityAdapter):
