@@ -17,7 +17,7 @@
 """cubicweb-queueing ui configuration"""
 
 
-from cubicweb.web import uicfg
+from cubicweb.web.views import uicfg
 
 _pvs = uicfg.primaryview_section
 _abaam = uicfg.actionbox_appearsin_addmenu
